//+------------------------------------------------------------------+
//|                                              		    eMarti.mq5 |
//|              Copyright Copyright 2010, MetaQuotes Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2010, MetaQuotes Software Corp."
#property link      "http://www.mql5.com"
#property version   "1.00"

#include "ExpertAdvisor.mqh"
#include <Trade\DealInfo.mqh>

input double Lots=0.1;  // Lot
input double LotKoef=2; // lot multiplier for loss
input int Dist=60;      // distance to Stop Loss and Take Profit
//---
class CMartiEA : public CExpertAdvisor
  {
protected:
   double            m_lots;       // Lot
   double            m_lotkoef;    // lot multiplier for loss
   int               m_dist;       // distance to Stop Loss and Take Profit
   CDealInfo         m_deal;       // last deal
   bool              m_first;      // flag of opening the first deal

public:
   void CMartiEA() { }
   void ~CMartiEA() { }
   virtual bool      Init(string smb,ENUM_TIMEFRAMES tf); // initialization
   virtual void      OpenPosition();
   virtual void      CheckPosition();
  };
//------------------------------------------------------------------	Init
bool CMartiEA::Init(string smb,ENUM_TIMEFRAMES tf)
  {
   if(!CExpertAdvisor::Init(0,smb,tf)) return(false); // initialize parent class
   m_lots=Lots; m_lotkoef=LotKoef; m_dist=Dist;       // copy parameters
   m_deal.Ticket(0); m_first=true;
   m_bInit=true; return(true);                        // trade allowed
  }
//------------------------------------------------------------------	OnTrade
void CMartiEA::OpenPosition()
  {
   if(!CExpertAdvisor::Main()) return;                       // call parent function
   if(!m_first) return;                                      // if already opened initial position
   ulong deal=DealOpen(ORDER_TYPE_BUY,m_lots,m_dist,m_dist); // open initial position
   if(deal>0) { m_deal.Ticket(deal); m_first=false; }        // if position exists
  }
//------------------------------------------------------------------	OnTrade
void CMartiEA::CheckPosition()
  {
   if(!CExpertAdvisor::Main()) return; // call parent function
   if(m_first) return;                 // if not yet opened initial position 
   if(PositionSelect(m_smb)) return;   // if position exists

   // check profit of previous position
   double lot=m_lots;                       // initial lot
   long dir=m_deal.Type();                  // previous direction
   if(CountProfitByDeal(m_deal.Ticket())<0) // if there was loss
     {
      lot=NormalLot(m_lotkoef*m_deal.Volume()); // increase lot
      dir=ReversType(m_deal.Type());            // reverse position
     }
   ulong deal=DealOpen(dir,lot,m_dist,m_dist); // open position
   if(deal>0) m_deal.Ticket(deal);             // remember ticket
  }

CMartiEA ea; // class instance
//------------------------------------------------------------------	OnInit
int OnInit()
  {
   ea.Init(Symbol(),Period()); // initialize expert
   return(0);
  }
//------------------------------------------------------------------	OnDeinit
void OnDeinit(const int reason) { }
//------------------------------------------------------------------	OnTick
void OnTick()
  {
   ea.OpenPosition(); // process tick - open the first tick of order
  }
//------------------------------------------------------------------	OnTrade
void OnTrade()
  {
   ea.CheckPosition(); // process trade event
  }